@@ -59,8 +59,7 @@ class OperationList(list):
         if not invocation in self:
             raise LookupError
 
-        compatible = [i for i in self if i == invocation]
-        return sorted(compatible)[0]
+        return [i for i in self if i == invocation][-1]
 
     def show(self, indent=0):
         if not self:
